@@ -46,7 +46,8 @@ _ENVIRON_HEADERS = {'auth_token': ['HTTP_X_AUTH_TOKEN',
                     'user_domain': ['HTTP_X_USER_DOMAIN_ID'],
                     'project_domain': ['HTTP_X_PROJECT_DOMAIN_ID'],
                     'user_name': ['HTTP_X_USER_NAME'],
-                    'project_name': ['HTTP_X_PROJECT_NAME'],
+                    'project_name': ['HTTP_X_PROJECT_NAME',
+                                     'HTTP_X_TENANT_NAME'],
                     'user_domain_name': ['HTTP_X_USER_DOMAIN_NAME'],
                     'project_domain_name': ['HTTP_X_PROJECT_DOMAIN_NAME'],
                     'request_id': ['openstack.request_id'],
